@@ -31,6 +31,11 @@ class Scaffold(object):
         self.lookup = lookup
         self.extensions = extensions
 
+
+    @property
+    def marker_comments(self):
+        return getattr(self.template, "marker_comments", {})
+
     @property
     def source_directory(self):
         return self.template.source_directory
@@ -51,15 +56,14 @@ class Scaffold(object):
                 for subsub in sub.iterate_children(iterated=iterated):
                     yield subsub
 
-    def walk(self, walker, dst, overwrite=True):
+    def walk(self, walker, dst, overwrite=True, skiptop=False):
         if hasattr(self.template, "cache"):
             walker.input.update(self.template.cache)
 
         ## todo: reserved word "extensions"
         if self.extensions is not None: #xxx:
             walker.input.update({":extensions:": self.extensions})
-
-        walker.walk(self.source_directory, dst, overwrite=overwrite)
+        walker.walk(self.source_directory, dst, overwrite=overwrite, skiptop=skiptop)
         for sub_scaffold in self.iterate_children():
             sub_scaffold.walk(walker, dst, overwrite=overwrite)
 
@@ -79,8 +83,9 @@ class ScaffoldGetter(object):
         self.out = out
         self.factory = factory
 
-    def iterate_scaffolds(self):
-        eps = list(pkg_resources.iter_entry_points(self.entry_points_name))
+    def iterate_scaffolds(self, entry_points_name=None):
+        entry_points_name = entry_points_name or self.entry_points_name
+        eps = list(pkg_resources.iter_entry_points(entry_points_name))
         for entry in eps:
             try:
                 scaffold_class = entry.load()
@@ -89,9 +94,10 @@ class ScaffoldGetter(object):
                 self.out('Warning: could not load entry point %s (%s: %s)' % (
                     entry.name, e.__class__.__name__, e))
 
-    def all_scaffolds(self):
+    def all_scaffolds(self, entry_points_name=None):
+        entry_points_name = entry_points_name or self.entry_points_name
         scaffolds = OrderedDict()
-        for name, scaffold_class in self.iterate_scaffolds():
+        for name, scaffold_class in self.iterate_scaffolds(entry_points_name=entry_points_name):
             scaffolds[name] = scaffold_class
         return scaffolds
 
